const jwt = require("jsonwebtoken");

// Middleware zur Verifizierung des JWT-Tokens
const authenticateToken = (req, res, next) => {
  // Holen des Tokens aus dem Authorization Header
  const authHeader = req.headers["authorization"];
  const token = authHeader && authHeader.split(" ")[1]; // 'Bearer TOKEN'

  if (token == null) {
    return res.status(401).json({ message: "Kein Token bereitgestellt" });
  }

  // Überprüfen des Tokens
  jwt.verify(token, process.env.JWT_SECRET, (err, user) => {
    if (err) {
      return res.status(403).json({ message: "Ungültiger Token" });
    }

    // Wenn der Token gültig ist, wird der User in der Anfrage gespeichert
    req.user = user;

    // Anfrage geht weiter zur nächsten Middleware/Route
    next();
  });
};

module.exports = authenticateToken;
